@@ -81,12 +81,10 @@ def load_dynamic_serializer():
             rendered_components.update(dict.fromkeys(dynamic_imports))
 
         # Include custom code in the shared component.
-        rendered_components.update(
-            dict.fromkeys(component._get_all_custom_code()),
-        )
+        rendered_components.update(component._get_all_custom_code())
 
         rendered_components[
-            templates.STATEFUL_COMPONENT.render(
+            templates.stateful_component_template(
                 tag_name="MySSRComponent",
                 memo_trigger_hooks=[],
                 component=component,
@@ -111,10 +109,10 @@ def load_dynamic_serializer():
             else:
                 imports[lib] = names
 
-        module_code_lines = templates.STATEFUL_COMPONENTS.render(
+        module_code_lines = templates.stateful_components_template(
             imports=utils.compile_imports(imports),
             memoized_code="\n".join(rendered_components),
-        ).splitlines()[1:]
+        ).splitlines()
 
         # Rewrite imports from `/` to destructure from window
         for ix, line in enumerate(module_code_lines[:]):
