@@ -171,7 +171,7 @@ class ToastProps(NoExtrasAllowedProps):
 class Toaster(Component):
     """A Toaster Component for displaying toast notifications."""
 
-    library: str | None = "sonner@2.0.5"
+    library: str | None = "sonner@2.0.7"
 
     tag = "Toaster"
 
@@ -238,7 +238,7 @@ class Toaster(Component):
 
     @staticmethod
     def send_toast(
-        message: str | Var = "",
+        message: str | Var[str] = "",
         level: str | None = None,
         fallback_to_alert: bool = False,
         **props,
@@ -292,7 +292,7 @@ class Toaster(Component):
         return run_script(toast)
 
     @staticmethod
-    def toast_info(message: str | Var = "", **kwargs: Any):
+    def toast_info(message: str | Var[str] = "", **kwargs: Any) -> EventSpec:
         """Display an info toast message.
 
         Args:
@@ -305,7 +305,7 @@ class Toaster(Component):
         return Toaster.send_toast(message, level="info", **kwargs)
 
     @staticmethod
-    def toast_warning(message: str | Var = "", **kwargs: Any):
+    def toast_warning(message: str | Var[str] = "", **kwargs: Any) -> EventSpec:
         """Display a warning toast message.
 
         Args:
@@ -318,7 +318,7 @@ class Toaster(Component):
         return Toaster.send_toast(message, level="warning", **kwargs)
 
     @staticmethod
-    def toast_error(message: str | Var = "", **kwargs: Any):
+    def toast_error(message: str | Var[str] = "", **kwargs: Any) -> EventSpec:
         """Display an error toast message.
 
         Args:
@@ -331,7 +331,7 @@ class Toaster(Component):
         return Toaster.send_toast(message, level="error", **kwargs)
 
     @staticmethod
-    def toast_success(message: str | Var = "", **kwargs: Any):
+    def toast_success(message: str | Var[str] = "", **kwargs: Any) -> EventSpec:
         """Display a success toast message.
 
         Args:
@@ -344,7 +344,7 @@ class Toaster(Component):
         return Toaster.send_toast(message, level="success", **kwargs)
 
     @staticmethod
-    def toast_loading(message: str | Var = "", **kwargs: Any):
+    def toast_loading(message: str | Var[str] = "", **kwargs: Any) -> EventSpec:
         """Display a loading toast message.
 
         Args:
@@ -357,7 +357,7 @@ class Toaster(Component):
         return Toaster.send_toast(message, level="loading", **kwargs)
 
     @staticmethod
-    def toast_dismiss(id: Var | str | None = None):
+    def toast_dismiss(id: Var[str] | str | None = None) -> EventSpec:
         """Dismiss a toast.
 
         Args:
