@@ -3,15 +3,17 @@
 from __future__ import annotations
 
 import contextlib
+import datetime
 import inspect
 import os
 import shutil
+import sys
 import time
 from pathlib import Path
 from types import FrameType
 
 from rich.console import Console
-from rich.progress import MofNCompleteColumn, Progress, TimeElapsedColumn
+from rich.progress import MofNCompleteColumn, Progress, TaskID, TimeElapsedColumn
 from rich.prompt import Prompt
 
 from reflex.constants import LogLevel
@@ -31,7 +33,7 @@ _EMITTED_DEPRECATION_WARNINGS = set()
 _EMITTED_INFO = set()
 
 # Warnings which have been printed.
-_EMIITED_WARNINGS = set()
+_EMITTED_WARNINGS = set()
 
 # Errors which have been printed.
 _EMITTED_ERRORS = set()
@@ -79,7 +81,7 @@ def is_debug() -> bool:
     return _LOG_LEVEL <= LogLevel.DEBUG
 
 
-def print(msg: str, dedupe: bool = False, **kwargs):
+def print(msg: str, *, dedupe: bool = False, **kwargs):
     """Print a message.
 
     Args:
@@ -128,7 +130,7 @@ def should_use_log_file_console() -> bool:
     return environment.REFLEX_ENABLE_FULL_LOGGING.get()
 
 
-def print_to_log_file(msg: str, dedupe: bool = False, **kwargs):
+def print_to_log_file(msg: str, *, dedupe: bool = False, **kwargs):
     """Print a message to the log file.
 
     Args:
@@ -136,10 +138,10 @@ def print_to_log_file(msg: str, dedupe: bool = False, **kwargs):
         dedupe: If True, suppress multiple console logs of print message.
         kwargs: Keyword arguments to pass to the print function.
     """
-    log_file_console().print(msg, **kwargs)
+    log_file_console().print(f"[{datetime.datetime.now()}] {msg}", **kwargs)
 
 
-def debug(msg: str, dedupe: bool = False, **kwargs):
+def debug(msg: str, *, dedupe: bool = False, **kwargs):
     """Print a debug message.
 
     Args:
@@ -161,7 +163,7 @@ def debug(msg: str, dedupe: bool = False, **kwargs):
         print_to_log_file(f"[purple]Debug: {msg}[/purple]", **kwargs)
 
 
-def info(msg: str, dedupe: bool = False, **kwargs):
+def info(msg: str, *, dedupe: bool = False, **kwargs):
     """Print an info message.
 
     Args:
@@ -179,7 +181,7 @@ def info(msg: str, dedupe: bool = False, **kwargs):
         print_to_log_file(f"[cyan]Info: {msg}[/cyan]", **kwargs)
 
 
-def success(msg: str, dedupe: bool = False, **kwargs):
+def success(msg: str, *, dedupe: bool = False, **kwargs):
     """Print a success message.
 
     Args:
@@ -197,7 +199,7 @@ def success(msg: str, dedupe: bool = False, **kwargs):
         print_to_log_file(f"[green]Success: {msg}[/green]", **kwargs)
 
 
-def log(msg: str, dedupe: bool = False, **kwargs):
+def log(msg: str, *, dedupe: bool = False, **kwargs):
     """Takes a string and logs it to the console.
 
     Args:
@@ -225,7 +227,7 @@ def rule(title: str, **kwargs):
     _console.rule(title, **kwargs)
 
 
-def warn(msg: str, dedupe: bool = False, **kwargs):
+def warn(msg: str, *, dedupe: bool = False, **kwargs):
     """Print a warning message.
 
     Args:
@@ -235,31 +237,46 @@ def warn(msg: str, dedupe: bool = False, **kwargs):
     """
     if _LOG_LEVEL <= LogLevel.WARNING:
         if dedupe:
-            if msg in _EMIITED_WARNINGS:
+            if msg in _EMITTED_WARNINGS:
                 return
-            _EMIITED_WARNINGS.add(msg)
+            _EMITTED_WARNINGS.add(msg)
         print(f"[orange1]Warning: {msg}[/orange1]", **kwargs)
     if should_use_log_file_console():
         print_to_log_file(f"[orange1]Warning: {msg}[/orange1]", **kwargs)
 
 
-def _get_first_non_framework_frame() -> FrameType | None:
+@once
+def _exclude_paths_from_frame_info() -> list[Path]:
+    import importlib.util
+
     import click
+    import granian
+    import socketio
     import typing_extensions
 
     import reflex as rx
 
     # Exclude utility modules that should never be the source of deprecated reflex usage.
-    exclude_modules = [click, rx, typing_extensions]
+    exclude_modules = [click, rx, typing_extensions, socketio, granian]
+    modules_paths = [file for m in exclude_modules if (file := m.__file__)] + [
+        spec.origin
+        for m in [*sys.builtin_module_names, *sys.stdlib_module_names]
+        if (spec := importlib.util.find_spec(m)) and spec.origin
+    ]
     exclude_roots = [
         p.parent.resolve() if (p := Path(file)).name == "__init__.py" else p.resolve()
-        for m in exclude_modules
-        if (file := m.__file__)
+        for file in modules_paths
     ]
     # Specifically exclude the reflex cli module.
     if reflex_bin := shutil.which(b"reflex"):
         exclude_roots.append(Path(reflex_bin.decode()))
 
+    return exclude_roots
+
+
+def _get_first_non_framework_frame() -> FrameType | None:
+    exclude_roots = _exclude_paths_from_frame_info()
+
     frame = inspect.currentframe()
     while frame := frame and frame.f_back:
         frame_path = Path(inspect.getfile(frame)).resolve()
@@ -269,6 +286,7 @@ def _get_first_non_framework_frame() -> FrameType | None:
 
 
 def deprecate(
+    *,
     feature_name: str,
     reason: str,
     deprecation_version: str,
@@ -295,13 +313,13 @@ def deprecate(
         filename = Path(origin_frame.f_code.co_filename)
         if filename.is_relative_to(Path.cwd()):
             filename = filename.relative_to(Path.cwd())
-        loc = f"{filename}:{origin_frame.f_lineno}"
+        loc = f" ({filename}:{origin_frame.f_lineno})"
         dedupe_key = f"{dedupe_key} {loc}"
 
     if dedupe_key not in _EMITTED_DEPRECATION_WARNINGS:
         msg = (
             f"{feature_name} has been deprecated in version {deprecation_version}. {reason.rstrip('.').lstrip('. ')}. It will be completely "
-            f"removed in {removal_version}. ({loc})"
+            f"removed in {removal_version}.{loc}"
         )
         if _LOG_LEVEL <= LogLevel.WARNING:
             print(f"[yellow]DeprecationWarning: {msg}[/yellow]", **kwargs)
@@ -311,7 +329,7 @@ def deprecate(
             _EMITTED_DEPRECATION_WARNINGS.add(dedupe_key)
 
 
-def error(msg: str, dedupe: bool = False, **kwargs):
+def error(msg: str, *, dedupe: bool = False, **kwargs):
     """Print an error message.
 
     Args:
@@ -393,3 +411,47 @@ def timing(msg: str):
         yield
     finally:
         debug(f"[white]\\[timing] {msg}: {time.time() - start:.2f}s[/white]")
+
+
+class PoorProgress:
+    """A poor man's progress bar."""
+
+    def __init__(self):
+        """Initialize the progress bar."""
+        super().__init__()
+        self.tasks = {}
+        self.progress = 0
+        self.total = 0
+
+    def add_task(self, task: str, total: int):
+        """Add a task to the progress bar.
+
+        Args:
+            task: The task name.
+            total: The total number of steps for the task.
+
+        Returns:
+            The task ID.
+        """
+        self.total += total
+        task_id = TaskID(len(self.tasks))
+        self.tasks[task_id] = {"total": total, "current": 0}
+        return task_id
+
+    def advance(self, task: TaskID, advance: int = 1):
+        """Advance the progress of a task.
+
+        Args:
+            task: The task ID.
+            advance: The number of steps to advance.
+        """
+        if task in self.tasks:
+            self.tasks[task]["current"] += advance
+            self.progress += advance
+            _console.print(f"Progress: {self.progress}/{self.total}")
+
+    def start(self):
+        """Start the progress bar."""
+
+    def stop(self):
+        """Stop the progress bar."""
